pub fn fields_to_string(fields: &[AnimeField]) -> StringExpand description
Utility to convert a list of fields to a string (in the format expected by query objects)
pub fn fields_to_string(fields: &[AnimeField]) -> StringUtility to convert a list of fields to a string (in the format expected by query objects)